@@ -13,7 +13,7 @@ from garlicsim.general_misc import import_tools
 from garlicsim.general_misc import misc_tools
 from garlicsim.general_misc import cute_iter_tools
 from garlicsim.general_misc.reasoned_bool import ReasonedBool
-from garlicsim.general_misc.third_party.ordered_dict import OrderedDict
+from garlicsim.general_misc.nifty_collections import OrderedDict
 from garlicsim.general_misc import caching
 
 import garlicsim
